summaryrefslogtreecommitdiff
path: root/lisp/eshell/em-cmpl.el
diff options
context:
space:
mode:
authorGlenn Morris <rgm@gnu.org>2013-06-01 11:00:14 -0700
committerGlenn Morris <rgm@gnu.org>2013-06-01 11:00:14 -0700
commitd870df218e755a7c6445c9aa01e09d1f3a00c6be (patch)
tree7bc4d1650b77a187a05c74d23e016e0b41334c34 /lisp/eshell/em-cmpl.el
parent2db59b1de6467dade4fff20e5ed104213edf1e6d (diff)
downloademacs-d870df218e755a7c6445c9aa01e09d1f3a00c6be.tar.gz
* eshell/em-cmpl.el (eshell-cmpl-initialize): Replace obsolete alias
Diffstat (limited to 'lisp/eshell/em-cmpl.el')
-rw-r--r--lisp/eshell/em-cmpl.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/lisp/eshell/em-cmpl.el b/lisp/eshell/em-cmpl.el
index 4b952e0ee39..7120f639a70 100644
--- a/lisp/eshell/em-cmpl.el
+++ b/lisp/eshell/em-cmpl.el
@@ -285,13 +285,13 @@ to writing a completion function."
eshell-cmpl-restore-window-delay)
(set (make-local-variable 'pcomplete-use-paring)
eshell-cmpl-use-paring)
;; `pcomplete-arg-quote-list' should only be set after all the
;; load-hooks for any other extension modules have been run, which
;; is true at the time `eshell-mode-hook' is run
(add-hook 'eshell-mode-hook
(function
(lambda ()
- (set (make-local-variable 'pcomplete-arg-quote-list)
+ (set (make-local-variable 'comint-file-name-quote-list)
eshell-special-chars-outside-quoting))) nil t)
(add-hook 'pcomplete-quote-arg-hook 'eshell-quote-backslash nil t)
(define-key eshell-mode-map [(meta tab)] 'eshell-complete-lisp-symbol)
@@ -285,13 +285,13 @@ to writing a completion function."
(set (make-local-variable 'pcomplete-use-paring)
eshell-cmpl-use-paring)
- ;; `pcomplete-arg-quote-list' should only be set after all the
+ ;; `comint-file-name-quote-list' should only be set after all the
;; load-hooks for any other extension modules have been run, which
;; is true at the time `eshell-mode-hook' is run